==> glpi-0.78.2.tar.gz: glpi/front/auth.others.php <==
<?php

/*
 * @version $Id: auth.others.php 10411 2010-02-09 07:58:26Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("config", "w");

$config = new Config();

//Update CAS configuration
if (isset ($_POST["update"])) {
   $config->update($_POST);
   glpi_header($CFG_GLPI["root_doc"] . "/front/auth.others.php");
}

if (!isset($_GET["id"])) {
   $_GET["id"]="";
}

commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others");

showOtherAuthList($_SERVER['PHP_SELF']);

commonFooter();

?>

==> glpi_0.80.1.orig.tar.gz: glpi/front/auth.others.php <==
<?php

/*
 * @version $Id: auth.others.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("config", "w");

$config = new Config();

//Update CAS configuration
if (isset ($_POST["update"])) {
   $config->update($_POST);
   glpi_header($CFG_GLPI["root_doc"] . "/front/auth.others.php");
}

if (!isset($_GET["id"])) {
   $_GET["id"]="";
}

commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others");

showOtherAuthList($_SERVER['PHP_SELF']);

commonFooter();

?>
